#!/bin/bash

set -e

up () {
  docker network create pew-net || true

  # main caddy container
  docker build -t customcaddy:latest -f Dockerfile.caddy .

  docker run \
    --detach \
    --name caddy \
    --restart unless-stopped \
    --label com.centurylinklabs.watchtower.enable=false \
    --privileged \
    --volume /mammoth/archive:/www/bigcavemaps.com/files/paul/archive:ro \
    --volume /mammoth/archive/cavepedia/cavepedia-data/00_files:/www/bigcavemaps.com/files/cavepedia-data/00_files:ro \
    --volume /mammoth/archive/vpicc/public:/www/bigcavemaps.com/files/vpicc:ro \
    --volume /mammoth/archive/websites/wacz:/www/bigcavemaps.com/files/websites:ro \
    --volume /mammoth/gis/bigcavemaps.com:/www/bigcavemaps.com/index:ro \
    --volume /mammoth/gis/source/public:/www/bigcavemaps.com/files/gis/source/public:ro \
    --volume /mammoth/replayweb.page:/www/files/bigcavemaps.com/replayweb.page:ro \
    --volume /mammoth/files/seaturtle.pw:/www/seaturtle.pw/files:ro \
    --volume $HOME/scripts-private/lech/Caddyfile:/etc/caddy/Caddyfile:ro \
    --volume /mammoth/caddy/data:/data:rw \
    --publish 80:80 \
    --publish 443:443 \
    --publish 443:443/udp \
    --network pew-net \
    customcaddy:latest
}

down () {
  docker stop caddy || true
  docker rm caddy || true
}

logs () {
  docker logs --follow caddy
}

$@
