#!/bin/bash

set -e

up () {
  # Exposed on port 80 in pew-net  
  docker run \
    --detach \
    --name photoview \
    --restart unless-stopped \
    --env PHOTOVIEW_DATABASE_DRIVER=mysql \
    --env PHOTOVIEW_MYSQL_URL=photoview:photoview@tcp\(pv-mariadb\)/photoview \
    --env PHOTOVIEW_LISTEN_IP=photoview \
    --env PHOTOVIEW_LISTEN_PORT=80 \
    --env PHOTOVIEW_MEDIA_CACHE=/app/cache \
    --volume /mammoth/photoview/cache:/cache:rw \
    --volume /mammoth/photos:/photos:ro \
    --network pew-net \
    viktorstrate/photoview:2

  docker run \
    --detach \
    --name pv-mariadb \
    --restart unless-stopped \
    --env MYSQL_DATABASE=photoview \
    --env MYSQL_USER=photoview \
    --env MYSQL_PASSWORD=photoview \
    --env MYSQL_RANDOM_ROOT_PASSWORD=1 \
    --volume /mammoth/photoview/mysql:/var/lib/mysql:rw \
    --network pew-net \
    mariadb:10.5
}

down () {
  docker stop photoview || true
  docker stop pv-mariadb || true
  docker rm photoview || true
  docker rm pv-mariadb || true
}

logs () {
  docker logs --follow photoview
  docker logs --follow pv-mariadb
}

$@
